@@ -31,7 +31,8 @@
 # <https://www.gnu.org/licenses/>.
 
 # TODO: use UCR variables for update, upgrade, install and remove commands
-from __future__ import print_function
+
+from __future__ import annotations
 
 import os
 import re
@@ -39,8 +40,8 @@ import shlex
 import subprocess
 import sys
 import time
-from argparse import ArgumentParser, Namespace  # noqa: F401
-from typing import Any, Container, List, NoReturn, Optional, Sequence  # noqa: F401
+from argparse import ArgumentParser, Namespace
+from typing import Any, List, Literal, NoReturn, Sequence
 
 from univention.config_registry import ConfigRegistry, handler_set, handler_unset
 from univention.lib.policy_result import PolicyResultFailed, policy_result
@@ -51,11 +52,7 @@ from univention.updater.commands import (
 from univention.updater.locking import UpdaterLock, apt_lock
 
 
-try:
-    from typing_extensions import Literal  # noqa: F401
-    _JOB = Literal["add", "remove"]
-except ImportError:
-    _JOB = str  # type: ignore
+_JOB = Literal["add", "remove"]
 
 
 LOGNAME = '/var/log/univention/actualise.log'
@@ -74,7 +71,7 @@ class Tee(object):
     with the print statement
     """
 
-    def __init__(self, files: Sequence[str] = [], stdout: bool = True, filter: Optional[str] = None) -> None:
+    def __init__(self, files: Sequence[str] = [], stdout: bool = True, filter: str | None = None) -> None:
         self.stdout = stdout
         self.files = files
         self.filter = filter
@@ -316,7 +313,7 @@ def remove_temp() -> None:
                 print('Warning: Deleting `%s` from incomplete update.' % filename)
                 os.remove(filename)
             del dirs[:]
-    except EnvironmentError:
+    except OSError:
         print('Failed, aborting.')
         sys.exit(2)
 
