@@ -99,7 +99,7 @@ define([
 		buildRendering: function() {
 			this.inherited(arguments);
 			domClass.add(this.domNode, 'umcUpdatesPage');
-			var ucs_version = "";
+
 			var widgets = [{ // --------------------- Reboot pane -----------------------------
 					type: HiddenInput,
 					name: 'reboot_required'
@@ -158,6 +158,7 @@ define([
 								to_show = true;
 								element_releases.set('value', val);
 							}
+
 							var componentQueryDeferred = new Deferred();
 							var appliance_mode = (this._form.getWidget('appliance_mode').get('value') === 'true');
 							var blockingComponents = this._form.getWidget('release_update_blocking_components').get('value');
@@ -168,16 +169,10 @@ define([
 								to_show = false;
 							}
 							var updatestext = '';
-
-							var updatestextdrop5_1 = '';
-							if (blockingComponents.length === 0 && values.some(value => value.id.indexOf('5.2-') === 0) && ucs_version.indexOf('5.0-') === 0) {
-								updatestextdrop5_1 = _('Note: UCS 5.1-0 is missing in this list on purpose. UCS 5.1-0 is not meant to be installed directly and may not fully work; it is just an <a href="https://www.univention.com/blog-en/2023/06/announcement-ucs-release-5-2/" target="_blank" rel="noopener noreferrer">intermediate release on the way to UCS 5.2-0</a>.\n')
-							}
-
 							var updatesTextComponentsUnknown = '';
 							var componentsUnknown = blockingComponents;
 							if (blockingComponents.length && !appliance_mode) {
-								updatestext = updatestext + _('Further release updates are available but cannot be installed.');
+								updatestext = _('Further release updates are available but cannot be installed.');
 								var updatesTextComponentsApps = '';
 								var askAppCenter = tools.umcpCommand('appcenter/get_by_component_id', {component_id: blockingComponents}, false).then(lang.hitch(this, function(data) {
 									var apps = data.result;
@@ -234,31 +229,25 @@ define([
 										}
 									}
 									updatestext = updatestext + ' ' + updatesTextComponentsApps + ' ' + updatesTextComponentsUnknown;
+									element_updatestext.set('content', updatestext);
+									this._form.showWidget('ucs_updates_text', true);
 								}));
 							} else {
 								componentQueryDeferred.resolve();
 							}
 
-							componentQueryDeferred.then(lang.hitch(this, function() {
-								if (updatestext || updatestextdrop5_1) {
-									updatestext = updatestext + ' ' + updatestextdrop5_1;
-									element_updatestext.set('content', updatestext);
-									this._form.showWidget('ucs_updates_text', true);
-								}
+							// hide or show combobox, spacers and corresponding button
+							this._form.showWidget('releases', to_show);
 
-								// hide or show combobox, spacers and corresponding button
-								this._form.showWidget('releases', to_show);
+							var but = this._form._buttons.run_release_update;
+							but.set('visible', to_show);
 
-								var but = this._form._buttons.run_release_update;
-								but.set('visible', to_show);
+							// renew affordance to check for package updates, but only
+							// if we didn't see availability yet.
+							if (!this._updates_available) {
+								this._set_updates_button(false, _("Package update status not yet checked"));
+							}
 
-								// renew affordance to check for package updates, but only
-								// if we didn't see availability yet.
-								if (!this._updates_available) {
-									this._set_updates_button(false, _("Package update status not yet checked"));
-								}
-
-							}));
 							this.standbyDuring(all([componentQueryDeferred, this._check_dist_upgrade(), this._check_app_updates()]));
 						} catch(error)
 						{
@@ -422,7 +411,6 @@ define([
 				try {
 					this.onQuerySuccess('updater/updates/get');
 					var values = this._form.get('value');
-					ucs_version = values.ucs_version;
 
 					// send event that value have been loaded
 					this.onStatusLoaded(values);
@@ -437,7 +425,6 @@ define([
 					} else {
 						vtxt = lang.replace(_("The currently installed release version is {ucs_version}."), values);
 					}
-
 					this._form.getWidget('ucs_version_text').set('content', vtxt);
 
 					this._show_reboot_pane(tools.isTrue(values.reboot_required));
