@@ -36,21 +36,14 @@
 
 import importlib.util
 import os
-
-
-try:
-    from shlex import quote
-except ImportError:
-    from pipes import quote
-
-
 from datetime import datetime
 from hashlib import md5
 from os import getpid, stat
+from shlex import quote
 from time import time
 from traceback import format_exc
-from types import ModuleType  # noqa: F401
-from typing import Any, Callable, Dict, Iterable, List, Tuple, Union  # noqa: F401
+from types import ModuleType
+from typing import Any, Callable, Dict, Iterable, List, Tuple, Union
 
 import psutil
 from apt import Cache
@@ -140,7 +133,7 @@ class Watched_File(object):
                 try:
                     with open(self._file, 'rb') as fd:
                         hash_ = md5(fd.read()).hexdigest()
-                except EnvironmentError:
+                except OSError:
                     pass
                 else:
                     if hash_ != self._last_md5:
@@ -199,7 +192,7 @@ class Instance(Base):
 
     def _last_update(self) -> Dict[str, Any]:
         status_file = '/var/lib/univention-updater/univention-updater.status'
-        ret = {'last_update_failed': False, 'last_update_version': None}  # type: Dict[str, Any]
+        ret: Dict[str, Any] = {'last_update_failed': False, 'last_update_version': None}
         try:
             fstat = stat(status_file)
             mtime = datetime.fromtimestamp(fstat.st_mtime)
@@ -208,15 +201,15 @@ class Instance(Base):
                 return ret
 
             with open(status_file) as fd:
-                info = dict(
+                info: Dict[str, str] = dict(
                     line.strip().split('=', 1)  # type: ignore
                     for line in fd
-                )  # type: Dict[str, str]
+                )
 
             ret['last_update_failed'] = info.get('status') == 'FAILED'
             if ret['last_update_failed']:
                 ret['last_update_version'] = info.get('next_version')
-        except (ValueError, EnvironmentError) as exc:
+        except (OSError, ValueError) as exc:
             MODULE.error(str(exc))
 
         return ret
@@ -259,7 +252,7 @@ class Instance(Base):
         appliance_mode = ucr.is_true('server/appliance')
 
         available_versions, blocking_components = self.uu.get_all_available_release_updates()
-        result = [{'id': str(rel), 'label': 'UCS %s' % (rel,)} for rel in available_versions if rel.mm != (5, 1)]
+        result = [{'id': str(rel), 'label': 'UCS %s' % (rel,)} for rel in available_versions]
         #
         # appliance_mode=no ; blocking_comp=no  → add "latest version"
         # appliance_mode=no ; blocking_comp=yes →  no "latest version"
@@ -278,7 +271,7 @@ class Instance(Base):
         hooks=ListSanitizer(StringSanitizer(minimum=1), required=True),
     )
     @threaded
-    def call_hooks(self, request) -> None:
+    def call_hooks(self, request) -> Any:
         """Calls the specified hooks and returns data given back by each hook"""
         result = {}
         hookmanager = HookManager(HOOK_DIRECTORY)  # , raise_exceptions=False
@@ -308,10 +301,13 @@ class Instance(Base):
         apt.upgrade(dist_upgrade=True)
         for pkg in apt.get_changes():
             if pkg.marked_install:
+                assert pkg.candidate is not None
                 install.append((pkg.name, pkg.candidate.version))
             if pkg.marked_upgrade:
+                assert pkg.candidate is not None
                 update.append((pkg.name, pkg.candidate.version))
             if pkg.marked_delete:
+                assert pkg.installed is not None
                 remove.append((pkg.name, pkg.installed.version))
 
         return {
@@ -345,7 +341,7 @@ class Instance(Base):
 
     def status(self, request) -> None:  # TODO: remove unneeded things
         """One call for all single-value variables."""
-        result = {}  # type: Dict[str, Any]
+        result: Dict[str, Any] = {}
         ucr.load()
 
         try:
@@ -452,7 +448,7 @@ class Instance(Base):
         if count < 0:
             try:
                 return stat(fname).st_ctime
-            except EnvironmentError:
+            except OSError:
                 return 0
 
         # don't read complete file if we have an 'ignore' count
@@ -478,7 +474,7 @@ class Instance(Base):
                         lines.append(line.rstrip().decode('utf-8', 'replace'))
                         if (count > 0) and (len(lines) > count):
                             lines.pop(0)
-        except EnvironmentError:
+        except OSError:
             pass
         return lines
 
@@ -488,14 +484,14 @@ class Instance(Base):
     @simple_response
     def updater_job_status(self, job: str) -> Dict[str, Any]:  # TODO: remove this completely
         """Returns the status of the current/last update even if the job is not running anymore."""
-        result = {}  # type: Dict[str, Any]
+        result: Dict[str, Any] = {}
         try:
             with open(INSTALLERS[job]['statusfile']) as fd:
                 for line in fd:
                     fields = line.strip().split('=')
                     if len(fields) == 2:
                         result['_%s_' % fields[0]] = fields[1]
-        except EnvironmentError:
+        except OSError:
             pass
 
         result['running'] = self.__which_job_is_running() != ''
@@ -527,7 +523,7 @@ class Instance(Base):
         try:
             with open(logfile, 'rb') as fd:
                 self._logfile_start_line = sum(1 for line in fd)
-        except EnvironmentError:
+        except OSError:
             pass
 
         command = spec['command']
@@ -627,8 +623,8 @@ class HookManager:
         :param module_dir: path to directory that contains Python modules with hook functions
         :param raise_exceptions: if `False`, all exceptions while loading Python modules will be dropped and all exceptions while calling hooks will be caught and returned in result list
         """
-        self.__loaded_modules = {}  # type: Dict[str, ModuleType]
-        self.__registered_hooks = {}  # type: Dict[str, List[Callable[..., Any]]]
+        self.__loaded_modules: Dict[str, ModuleType] = {}
+        self.__registered_hooks: Dict[str, List[Callable[..., Any]]] = {}
         self.__module_dir = module_dir
         self.__raise_exceptions = raise_exceptions
         self.__load_hooks()
